%solid_heat_capacity
% Compares the Einstein model of molar heat capacity (using quantum
% oscillator ideas from Black Body radiation) temperature dependance  
% for various elements.
%
% LAST UPDATED by Andy French January 2016

function solid_heat_capacity

%Define fundamental constants

%Boltzmann's constant /m^2kgs^-2K^-1
kB = 1.3806504e-23;

%Planck's constant /m^2kgs^-1
h = 6.626068e-34;

%Speed of light /ms^-1
c = 299792458;

%Molar gas constant /Jmol^-1K^-1
R = 8.314;

%Define temperature ranges /K
Tmin = 0;
Tmax = 800;
Cmax = 3.2*R;

%Elements
elements = {
    'Au',...
    'Cu',...
    'Ti',...
    'Al',...
    'Fe',...
    'Si',...
    'C'
    };

%Define Debye temperature /K for elements
TD = [
    170,...
    343.5,...
    420,...
    428,...
    470,...
    645,...
    2230
    ];

%Number of data points for T values
N = 1000;

%Fontsize
fsize = 18;

%

%Compute Einstein temperature, and hence frequency /Hz
TE = TD*( (pi/6)^(1/3) );
fE = kB*TE/h;
fE = repmat( fE,[N,1] );

%Define temperatures /K
T = repmat( linspace(Tmin,Tmax,N).',[1,length(elements)] );

%Define Einstein model of molar heat capacity
x = h*fE./(kB*T);
C = 3*R*( x.^2 ).*exp(x)./(( exp(x) - 1).^2 );

%Plot graphs
figure('color',[1 1 1],'name','Einstein model of solid molar heat capacity');
plot(T,C);
legend(elements,'fontsize',fsize,'location','eastoutside');
xlabel('T /K','fontsize',fsize)
ylabel('Molar heat capacity / Jmol^{-1}K^{-1}','fontsize',fsize)
title('Einstein model of solid molar heat capacity','fontsize',fsize)
set(gca,'fontsize',fsize);
xlim([Tmin,Tmax])
ylim([0,Cmax])
grid on;
hold on;
plot([Tmin,Tmax],[3*R,3*R],'k--');
print(gcf,'solid heat capacity.png','-dpng','-r300');
close(gcf);

%End of code